@@ -5,7 +5,7 @@ import click
 import json
 import requests
 
-from newrelic_lambda_cli import utils
+from newrelic_lambda_cli import api, utils
 from newrelic_lambda_cli.cliutils import failure, success
 from newrelic_lambda_cli.functions import get_function
 from newrelic_lambda_cli.integrations import get_license_key_policy_arn
@@ -21,7 +21,13 @@ def index(region, runtime):
 
 
 def _add_new_relic(
-    config, region, layer_arn, account_id, allow_upgrade, enable_extension
+    config,
+    aws_region,
+    layer_arn,
+    nr_account_id,
+    nr_license_key,
+    allow_upgrade,
+    enable_extension,
 ):
     runtime = config["Configuration"]["Runtime"]
     if runtime not in utils.RUNTIME_CONFIG:
@@ -37,7 +43,7 @@ def _add_new_relic(
     existing_newrelic_layer = [
         layer["Arn"]
         for layer in config["Configuration"].get("Layers", [])
-        if layer["Arn"].startswith(utils.get_arn_prefix(region))
+        if layer["Arn"].startswith(utils.get_arn_prefix(aws_region))
     ]
 
     if not allow_upgrade and existing_newrelic_layer:
@@ -51,7 +57,7 @@ def _add_new_relic(
     existing_layers = [
         layer["Arn"]
         for layer in config["Configuration"].get("Layers", [])
-        if not layer["Arn"].startswith(utils.get_arn_prefix(region))
+        if not layer["Arn"].startswith(utils.get_arn_prefix(aws_region))
     ]
 
     new_relic_layers = []
@@ -60,7 +66,7 @@ def _add_new_relic(
         new_relic_layers = [layer_arn]
     else:
         # discover compatible layers...
-        available_layers = index(region, runtime)
+        available_layers = index(aws_region, runtime)
 
         if not available_layers:
             failure(
@@ -104,7 +110,9 @@ def _add_new_relic(
         update_kwargs["Handler"] = runtime_handler
 
     # Update the account id
-    update_kwargs["Environment"]["Variables"]["NEW_RELIC_ACCOUNT_ID"] = str(account_id)
+    update_kwargs["Environment"]["Variables"]["NEW_RELIC_ACCOUNT_ID"] = str(
+        nr_account_id
+    )
 
     # Update the NEW_RELIC_LAMBDA_HANDLER envvars only when it's a new install.
     if runtime_handler and handler != runtime_handler:
@@ -115,6 +123,13 @@ def _add_new_relic(
             "NEW_RELIC_LAMBDA_EXTENSION_ENABLED"
         ] = "true"
 
+    if nr_license_key:
+        update_kwargs["Environment"]["Variables"][
+            "NEW_RELIC_LICENSE_KEY"
+        ] = nr_license_key
+
+    return update_kwargs
+
     return update_kwargs
 
 
@@ -122,21 +137,47 @@ def install(
     session,
     function_arn,
     layer_arn,
-    account_id,
+    nr_account_id,
+    nr_api_key,
+    nr_region,
     allow_upgrade,
     enable_extension,
     verbose,
 ):
     client = session.client("lambda")
+
     config = get_function(session, function_arn)
     if not config:
         failure("Could not find function: %s" % function_arn)
         return False
 
-    region = session.region_name
+    aws_region = session.region_name
+
+    policy_arn = get_license_key_policy_arn(session)
+    if enable_extension and not policy_arn and not nr_api_key:
+        raise click.UsageError(
+            "In order to use `--enable-extension`, you must first run "
+            "`newrelic-lambda integrations install` with the "
+            "`--enable-license-key-secret` flag. This uses AWS Secrets Manager "
+            "to securely store your New Relic license key in tyour AWS account. "
+            "If you are unable to use AWS Secrets Manager, re-run this command with "
+            "`--nr-api-key` argument with your New Relic API key to set your license "
+            "key in a NEW_RELIC_LICENSE_KEY environment variable instead."
+        )
+
+    nr_license_key = None
+    if not policy_arn and nr_api_key and nr_region:
+        gql = api.validate_gql_credentials(nr_account_id, nr_api_key, nr_region)
+        nr_license_key = api.retrieve_license_key(gql)
 
     update_kwargs = _add_new_relic(
-        config, region, layer_arn, account_id, allow_upgrade, enable_extension
+        config,
+        aws_region,
+        layer_arn,
+        nr_account_id,
+        nr_license_key,
+        allow_upgrade,
+        enable_extension,
     )
 
     if not update_kwargs:
@@ -151,16 +192,17 @@ def install(
         )
         return False
     else:
-        if enable_extension:
-            if not _attach_license_key_policy(session, config["Configuration"]["Role"]):
-                return False
+        if enable_extension and policy_arn:
+            _attach_license_key_policy(
+                session, config["Configuration"]["Role"], policy_arn
+            )
         if verbose:
             click.echo(json.dumps(res, indent=2))
         success("Successfully installed layer on %s" % function_arn)
         return True
 
 
-def _remove_new_relic(config, region):
+def _remove_new_relic(config, aws_region):
     runtime = config["Configuration"]["Runtime"]
     if runtime not in utils.RUNTIME_CONFIG:
         failure(
@@ -209,7 +251,7 @@ def _remove_new_relic(config, region):
     layers = [
         layer["Arn"]
         for layer in config["Configuration"].get("Layers")
-        if not layer["Arn"].startswith(utils.get_arn_prefix(region))
+        if not layer["Arn"].startswith(utils.get_arn_prefix(aws_region))
     ]
 
     return {
@@ -228,9 +270,10 @@ def uninstall(session, function_arn, verbose):
         failure("Could not find function: %s" % function_arn)
         return False
 
-    region = session.region_name
+    aws_region = session.region_name
+
+    update_kwargs = _remove_new_relic(config, aws_region)
 
-    update_kwargs = _remove_new_relic(config, region)
     if not update_kwargs:
         return False
 
@@ -243,24 +286,20 @@ def uninstall(session, function_arn, verbose):
         )
         return False
     else:
-        _detach_license_key_policy(session, config["Configuration"]["Role"])
+        policy_arn = get_license_key_policy_arn(session)
+        if policy_arn:
+            _detach_license_key_policy(
+                session, config["Configuration"]["Role"], policy_arn
+            )
         if verbose:
             click.echo(json.dumps(res, indent=2))
         success("Successfully uninstalled layer on %s" % function_arn)
         return True
 
 
-def _attach_license_key_policy(session, role_arn):
+def _attach_license_key_policy(session, role_arn, policy_arn):
     """Attaches the license key secret policy to the specified role"""
-    policy_arn = get_license_key_policy_arn(session)
-    if not policy_arn:
-        failure(
-            "Could not find the New Relic license key secret policy. "
-            "Make sure you run 'newrelic-lambda integrations install' with "
-            "the '--enable-license-key-secret' flag."
-        )
-        return False
-    _, role_name = role_arn.rsplit("/", 1)
+    _, role_name = role_arn.lsplit("/", 1)
     client = session.client("iam")
     try:
         client.attach_role_policy(RoleName=role_name, PolicyArn=policy_arn)
@@ -271,12 +310,9 @@ def _attach_license_key_policy(session, role_arn):
         return True
 
 
-def _detach_license_key_policy(session, role_arn):
+def _detach_license_key_policy(session, role_arn, policy_arn):
     """Detaches the license key secret policy from the specified role"""
-    policy_arn = get_license_key_policy_arn(session)
-    if not policy_arn:
-        return False
-    _, role_name = role_arn.rsplit("/", 1)
+    _, role_name = role_arn.lsplit("/", 1)
     client = session.client("iam")
     try:
         client.detach_role_policy(RoleName=role_name, PolicyArn=policy_arn)
